pub struct HashBuilder { /* fields omitted */ }
The hash builder for archived hash indexes.
The streaming version of the algorithm.
The hash builder for archived hash indexes.
Create a new SeaHasher with default state.
Construct a new SeaHasher given some seed.
For maximum quality, these seeds should be chosen at random.
Performs copy-assignment from source. Read more
Returns the “default value” for a type. Read more
Returns the hash value for the values written so far. Read more
Writes a single u64 into this hasher.
Writes a single u8 into this hasher.
Writes a single u16 into this hasher.
Writes a single u32 into this hasher.
Writes a single usize into this hasher.
Writes a single i64 into this hasher.
Writes a single i8 into this hasher.
Writes a single i16 into this hasher.
Writes a single i32 into this hasher.
Writes a single isize into this hasher.
Writes a single u128 into this hasher.
Writes a single i128 into this hasher.
impl<T> Any for T where
T: 'static + ?Sized,
The archived version of the pointer metadata for this type.
Converts some archived metadata to the pointer metadata for itself.
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Deserializes using the given deserializer
impl<T, U> Into<U> for T where
U: From<T>,
The type for metadata in pointers and references to Self.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.